@@ -8,6 +8,14 @@ from ryry import utils
 from ryry import taskUtils
 from ryry import proxy_manager
 
+# 获取版本信息的兼容函数
+def get_version():
+    try:
+        from importlib.metadata import version
+        return version("ryry-cli")
+    except ImportError:
+        from importlib_metadata import version
+        return version("ryry-cli")
 ll = 29
 def scr_str(s):
     return "| " + s + " |"
@@ -161,8 +169,7 @@ def widget_status(stdscr, idx):
     return idx
 
 def status():
-    from pkg_resources import parse_version, get_distribution
-    ver = get_distribution("ryry-cli").version
+    ver = get_version()
     deviceid = utils.generate_unique_id()
     import socket
     machine_name = socket.gethostname()
@@ -207,8 +214,8 @@ def status():
         service_status(None, 0)
         print(scr_line("-" * ll*3))
         device_status(None, 0)
-        print(scr_line("-" * ll*3))
-        proxy_status(None, 0)
+        # print(scr_line("-" * ll*3))
+        # proxy_status(None, 0)
         print(scr_line("-" * ll*3))
         widget_status(None, 0)
         print(scr_line("-" * ll*3))
@@ -329,10 +336,6 @@ def get_widget_config_from_path(main_path):
         pass
     return None
 
-
-
-
-
 def widget():
     if len(sys.argv) <= 2:
         print('please set command! Usage: ryry widget [init|publish|list|add|remove|enable|disable|install]')
@@ -397,6 +400,23 @@ def widget():
     else:
         print("Unknown command:", command)
 
+def token():
+    if len(sys.argv) <= 2:
+        print('please set command! Usage: ryry token [set/get]')
+        return
+    
+    command = sys.argv[2]
+    if command == 'set':
+        user_token = sys.argv[3]
+        store.save_authorization(user_token)
+        print("✅ token saved")
+    elif command == 'get':
+        user_token, author = store.get_token_and_authorization()
+        print(f"Usertoken: {user_token}")
+        print(f"Authorization: {author}")
+    else:
+        print("Unknown command:", command)
+    
 def proxy():
     """代理管理功能"""
     if len(sys.argv) <= 2:
@@ -447,6 +467,10 @@ def main():
     if len(sys.argv) >= 2:
         module = sys.argv[1]
         if module == "widget":
+            _, author = store.get_token_and_authorization()
+            if not author or len(author) < 3:
+                print("❌ token not found, please set token first")
+                sys.exit(0)
             widget()
         elif module == "service":
             service()
@@ -454,6 +478,8 @@ def main():
             status()
         elif module == "proxy":
             proxy()
+        elif module == "token":
+            token()
         else:
             print(f"Unknown command:{module}")
             sys.exit(0)
