@@ -9,10 +9,12 @@ from urllib.parse import urlparse, urlunparse
 
 from ryry import store, utils, taskUtils, constant, task
 
+user_token, author = store.get_token_and_authorization()
 def _domain_post(func, params, files={}, timeout=10, domain="api.dalipen.com"):
     headers = {
         'Connection': 'close',
-        'Usertoken': "0cce7cfe3629e16ee9b3ea8563305d3a15c524804da1861db07c2c867d79da63"
+        'Usertoken': user_token,
+        'Authorization': f"Bearer {author}"
     }
     url = f"https://{domain}/{func}"
     try:
@@ -41,6 +43,19 @@ def _aigc_post(func, params, files={}, timeout=10):
     if status != -99:
         return status, msg, data
     return _domain_post(func, params, files, timeout, "aigc.zjtemplate.com")
+
+def set_authorization(author):
+    store.save_authorization(author)
+    if checkLicense():
+        print("✅ license check success")
+    else:
+        print("❌ license check failed")
+def set_user_token(user_token):
+    store.save_user_token(user_token)
+    if checkLicense():
+        print("✅ license check success")
+    else:
+        print("❌ license check failed")
 #======================================== Task Function ==============================
 def ServerTaskConfig():
     r1, r2, r3 = _aigc_post("aigc/task/config", {})
