@@ -1,11 +1,38 @@
-import os, json,sys,shutil,zipfile,pkg_resources,threading,time,requests
+import os, json,sys,shutil,zipfile,threading,time,requests
 import random, uuid, re, subprocess, platform, zipfile
-from pkg_resources import get_distribution
 import socket
 
 from pathlib import Path
 from ryry import store, ryry_webapi, upload, taskUtils, utils, constant
 
+# 获取版本信息的兼容函数
+def get_version():
+    try:
+        from importlib.metadata import version
+        return version("ryry-cli")
+    except ImportError:
+        from importlib_metadata import version
+        return version("ryry-cli")
+
+# 获取包信息的兼容函数
+def get_package_info(package_name):
+    try:
+        from importlib.metadata import distribution
+        dist = distribution(package_name)
+        return {
+            'version': dist.version,
+            'project_name': dist.metadata['Name'],
+            'location': dist.locate_file('')
+        }
+    except ImportError:
+        from importlib_metadata import distribution
+        dist = distribution(package_name)
+        return {
+            'version': dist.version,
+            'project_name': dist.metadata['Name'],
+            'location': dist.locate_file('')
+        }
+
 def compare_versions(version1, version2):
     if len(version1) <= 0:
         version1 = "0"
@@ -127,11 +154,11 @@ def addWidgetToEnv(name_or_root, mute=False):
     #maybe pip package
     root = ""
     try:
-        package = pkg_resources.get_distribution(name_or_root)
-        local_version = package.version
-        name = package.project_name
-        version = package.version
-        root = os.path.join(package.location, name.replace("-", "_"))
+        package_info = get_package_info(name_or_root)
+        local_version = package_info['version']
+        name = package_info['project_name']
+        version = package_info['version']
+        root = os.path.join(package_info['location'], name.replace("-", "_"))
     except:
         pass
     
@@ -262,7 +289,7 @@ def publishWidget(package_folder):
 def widgetUpdateNotify(widgetName, oldver, newver):
     device_id = utils.generate_unique_id()
     machine_name = socket.gethostname()
-    ver = get_distribution("ryry-cli").version
+    ver = get_version()
     taskUtils.notifyWechatRobot({
         "msgtype": "text",
         "text": {
@@ -273,7 +300,7 @@ def widgetUpdateNotify(widgetName, oldver, newver):
 def widgetUninstallNotify(widgetName, newver):
     device_id = utils.generate_unique_id()
     machine_name = socket.gethostname()
-    ver = get_distribution("ryry-cli").version
+    ver = get_version()
     taskUtils.notifyWechatRobot({
         "msgtype": "text",
         "text": {
@@ -284,7 +311,7 @@ def widgetUninstallNotify(widgetName, newver):
 def widgetInstallNotify(widgetName, newver):
     device_id = utils.generate_unique_id()
     machine_name = socket.gethostname()
-    ver = get_distribution("ryry-cli").version
+    ver = get_version()
     taskUtils.notifyWechatRobot({
         "msgtype": "text",
         "text": {
